@@ -48,7 +48,7 @@ class Notification(object):
              type - The notification type
              name - Name used in sending
              address - where to send the notification
-             period - period of sending the notificationv
+             period - period of sending the notification
              retry_count - number of times we've tried to send
              alarm - info that caused the notification
              notifications that come after this one to remain uncommitted.
@@ -65,7 +65,7 @@ class Notification(object):
         self.alarm_id = alarm['alarmId']
         self.alarm_name = alarm['alarmName']
         # The event timestamp is in milliseconds
-        self.alarm_timestamp = alarm['timestamp'] / 1000
+        self.alarm_timestamp = int(alarm['timestamp'] / 1000.0)
         self.message = alarm['stateChangeReason']
         self.state = alarm['newState']
         self.severity = alarm['severity']
